@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2005-2009  Craig Barratt
+#   Copyright (C) 2005-2017  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.2.1, released 24 Apr 2011.
+# Version 3.3.2, released 25 Jan 2017.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -451,7 +451,7 @@ sub action
         # based on what is enabled.  Admin users can edit all the
         # available per-host settings.
         #
-        foreach my $m ( keys(%ConfigMenu) ) {
+        foreach my $m ( sort(keys(%ConfigMenu)) ) {
             my $enabled = 0;
             my $text = -1;
             my $n = 0;
@@ -492,7 +492,7 @@ sub action
     }
 
     my $groupText;
-    foreach my $m ( keys(%ConfigMenu) ) {
+    foreach my $m ( sort(keys(%ConfigMenu)) ) {
         next if ( $menuDisable{$m}{top} );
 	my $text = eval("qq($Lang->{$ConfigMenu{$m}{text}})");
         if ( $m eq $menu ) {
@@ -1201,9 +1201,10 @@ EOF
         }
 
         if ( !$type->{noKeyEdit} ) {
+            my $keyText = defined($type->{keyText}) ? $Lang->{$type->{keyText}} : $Lang->{CfgEdit_Button_New_Key};
             $content .= <<EOF;
 <tr><td class="border" colspan="2">
-$Lang->{CfgEdit_Button_New_Key}: <input type="text" class="editTextInput" name="addVarKey_$varName" size="20" maxlength="256" value="">
+$keyText: <input type="text" class="editTextInput" name="addVarKey_$varName" size="20" maxlength="256" value="">
 <input type="button" name="add_$varName" value="${EscHTML($Lang->{CfgEdit_Button_Add})}" onClick="addSubmit('$varName', 1)">
 </td></tr>
 EOF
