@@ -10,7 +10,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2004-2009  Craig Barratt
+#   Copyright (C) 2004-2017  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -28,7 +28,7 @@
 #
 #========================================================================
 #
-# Version 3.2.1, released 24 Apr 2011.
+# Version 3.3.2, released 25 Jan 2017.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -152,6 +152,7 @@ use vars qw(%ConfigMeta);
 
     BackupFilesOnly	=> {
             type      => "hash",
+            keyText   => "CfgEdit_Button_New_Share",
             emptyOk   => 1,
             childType => {
                 type      => "list",
@@ -161,6 +162,7 @@ use vars qw(%ConfigMeta);
     },
     BackupFilesExclude	=> {
             type      => "hash",
+            keyText   => "CfgEdit_Button_New_Share",
             emptyOk   => 1,
             childType => {
                 type      => "list",
@@ -351,7 +353,7 @@ use vars qw(%ConfigMeta);
     CgiURL	 	=> "string",
     Language	 	=> {
 	    type   => "select",
-	    values => [qw(cz de en es fr it nl pl pt_br zh_CN)],
+	    values => [qw(cz de en es fr it ja nl pl pt_br ru uk zh_CN)],
     },
     CgiUserHomePageCheck => "string",
     CgiUserUrlCreate    => "string",
