@@ -542,8 +542,15 @@ evtl. die Dateien/Verzeichnisse erneut und lassen sehr groe und unntige Dateien
  \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (andernfalls enthlt die Archiv Datei vollstndige Pfade).
 <br>
-Kompression (0=aus, 1=schnelle,...,9=hchste)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Kompression (0=aus, 1=schnelle,...,9=hchste)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Zip Datei downloaden" name="ignore">
 </form>
@@ -835,7 +842,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Inhalt von \${EscHTML(\$dirDisplay)}")}
+\${h2("Inhalt von \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -890,7 +897,7 @@ Diese Ansicht zeigt alle unterschiedlichen Versionen der Dateien in den Datensic
 <li> Dateien mit der gleichen Version knnen unterschiedliche Attribute haben. Whlen Sie die Datensicherungsnummer um die Attribute anzuzeigen.
 </ul>
 
-\${h2("Historie von \${EscHTML(\$dirDisplay)}")}
+\${h2("Historie von \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -980,7 +987,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Nur berechtigte Benutzer knnen Backups starten und stoppen fr"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "ungltige Nummer \$num";
+$Lang{Invalid_number__num} = "ungltige Nummer \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "kann Datei nicht ffnen \$file: Konfigurationsproblem?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Nur berechtigte Benutzer knnen Log oder Config Dateien einsehen.";
 $Lang{Only_privileged_users_can_view_log_files} = "Nur berechtigte Benutzer knnen LOG Dateien einsehen.";
@@ -1209,7 +1216,7 @@ $Lang{No} = "nein";
 $Lang{Yes} = "ja";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">Das Verzeichnis \${EscHTML(\$dirDisplay)} ist leer.
+<tr><td bgcolor="#ffffff">Das Verzeichnis \$dirDisplay ist leer.
 </td></tr>
 EOF
 
@@ -1412,7 +1419,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Andere";
 $Lang{CfgEdit_Title_Backup_Settings} = "Backup Einstellungen";
 $Lang{CfgEdit_Title_Client_Lookup} = "Auflsen des Klienten";
-$Lang{CfgEdit_Title_Other} = "Andere Werte";
 $Lang{CfgEdit_Title_User_Commands} = "Benutzer Kommandos";
 $Lang{CfgEdit_Title_Hosts} = "Hosts";
 
@@ -1448,6 +1454,7 @@ $Lang{CfgEdit_Button_Delete}   = "Lschen";
 $Lang{CfgEdit_Button_Add}      = "Hinzufgen";
 $Lang{CfgEdit_Button_Override} = "berschreiben";
 $Lang{CfgEdit_Button_New_Key}  = "Neuer Schlssel";
+$Lang{CfgEdit_Button_New_Share} = "New ShareName or '*'";
 
 $Lang{CfgEdit_Error_No_Save}
             = "Wegen Fehlern nicht gesichert";
