@@ -541,8 +541,15 @@ abbastanza spazio sul proprio disco rigido locale per poterlo contenere.
 l\'archivio relativamente a \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (altrimenti l\'archivio conterr&agrave; percorsi completi).
 <br>
-Compressione (0=off, 1=fast,...,9=best)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compressione (0=off, 1=fast,...,9=best)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Scarica file zip" name="ignore">
 </form>
@@ -837,7 +844,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Contents of \${EscHTML(\$dirDisplay)}")}
+\${h2("Contents of \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -897,7 +904,7 @@ Questa videata mostra tutte le versioni uniche disponibili nei diversi backup:
      attributi del file.
 </ul>
 
-\${h2("Cronologia di \${EscHTML(\$dirDisplay)}")}
+\${h2("Cronologia di \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -987,7 +994,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
                   "Solo gli utenti privilegiati possono arrestare o avviare un backup su"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Numero non valido: \$num";
+$Lang{Invalid_number__num} = "Numero non valido: \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Impossibile aprire il file \$file: problema di configurazione?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Solo gli utenti privilegiati possono visualizzare i file di log o di configurazione.";
 $Lang{Only_privileged_users_can_view_log_files} = "Solo gli utenti privilegiati possono visualizzare i file di log.";
@@ -1219,7 +1226,7 @@ $Lang{No} = "no";
 $Lang{Yes} = "s&igrave;";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">La directory \${EscHTML(\$dirDisplay)} &egrave; vuota
+<tr><td bgcolor="#ffffff">La directory \$dirDisplay &egrave; vuota
 </td></tr>
 EOF
 
@@ -1419,7 +1426,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Altro";
 $Lang{CfgEdit_Title_Backup_Settings} = "Configurazione Backup";
 $Lang{CfgEdit_Title_Client_Lookup} = "Client Lookup";
-$Lang{CfgEdit_Title_Other} = "Altro";
 $Lang{CfgEdit_Title_User_Commands} = "Comandi Utente";
 $Lang{CfgEdit_Title_Hosts} = "Hosts";
 
@@ -1455,6 +1461,7 @@ $Lang{CfgEdit_Button_Delete}   = "Cancella";
 $Lang{CfgEdit_Button_Add}      = "Aggiungi";
 $Lang{CfgEdit_Button_Override} = "Sovrascrivi";
 $Lang{CfgEdit_Button_New_Key}  = "Nuova chiave";
+$Lang{CfgEdit_Button_New_Share} = "New ShareName or '*'";
 
 $Lang{CfgEdit_Error_No_Save}
             = "Errore: Non salvo poich&eacute; sono presenti errori";
