@@ -531,8 +531,15 @@ harde schijfruimte beschikken om het bestand te kunnen bevatten.
 aan \${EscHTML(\$pathHdr eq "" ? "/" : \$pathHdr)}
 (in het andere geval zal het archiefbestand volledige padnamen bevatten).
 <br>
-Compressie (0=uit, 1=snel,...,9=hoogst)
-<input type="text" size="6" value="5" name="compressLevel">
+<table class="tableStnd" border="0">
+<tr>
+    <td>Compressie (0=uit, 1=snel,...,9=hoogst)</td>
+    <td><input type="text" size="6" value="5" name="compressLevel"></td>
+</tr><tr>
+    <td>Code page (e.g. cp866)</td>
+    <td><input type="text" size="6" value="utf8" name="codePage"></td>
+</tr>
+</table>
 <br>
 <input type="submit" value="Download Zip-bestand" name="ignore">
 </form>
@@ -827,7 +834,7 @@ $Lang{Backup_browse_for__host} = <<EOF;
 </ul>
 </form>
 
-\${h2("Inhoud van \${EscHTML(\$dirDisplay)}")}
+\${h2("Inhoud van \$dirDisplay")}
 <form name="form1" method="post" action="\$MyURL">
 <input type="hidden" name="num" value="\$num">
 <input type="hidden" name="host" value="\$host">
@@ -888,7 +895,7 @@ alle backups heen:
      de attributen van het bestand te bekijken.
 </ul>
 
-\${h2("Geschiedenis van \${EscHTML(\$dirDisplay)}")}
+\${h2("Geschiedenis van \$dirDisplay")}
 
 <br>
 <table border cellspacing="2" cellpadding="3">
@@ -977,7 +984,7 @@ $Lang{Wrong_user__my_userid_is___} =
 $Lang{Only_privileged_users_can_stop_or_start_backups} = 
 		  "Enkel gebruikers met bijzondere rechten kunnen backups stoppen of starten van machine"
 		. " \${EscHTML(\$host)}.";
-$Lang{Invalid_number__num} = "Ongeldig of onjuist nummer \$num";
+$Lang{Invalid_number__num} = "Ongeldig of onjuist nummer \${EscHTML(\$In{num})}";
 $Lang{Unable_to_open__file__configuration_problem} = "Ik kan \$file niet openen: misschien problemen met de configuratie?";
 $Lang{Only_privileged_users_can_view_log_or_config_files} = "Enkel gebruikers met bijzondere rechten kunnen log- of configuratiebestanden bekijken.";
 $Lang{Only_privileged_users_can_view_log_files} = "Enkel gebruikers met bijzondere rechten kunnen logbestanden bekijken.";
@@ -1207,7 +1214,7 @@ $Lang{No} = "nee";
 $Lang{Yes} = "ja";
 
 $Lang{The_directory_is_empty} = <<EOF;
-<tr><td bgcolor="#ffffff">De map/directory \${EscHTML(\$dirDisplay)} is leeg
+<tr><td bgcolor="#ffffff">De map/directory \$dirDisplay is leeg
 </td></tr>
 EOF
 
@@ -1417,7 +1424,6 @@ $Lang{CfgEdit_Title_Blackouts} = "Blackouts";
 $Lang{CfgEdit_Title_Other} = "Andere";
 $Lang{CfgEdit_Title_Backup_Settings} = "Backup instellingen";
 $Lang{CfgEdit_Title_Client_Lookup} = "Cli&euml;nt locatie";
-$Lang{CfgEdit_Title_Other} = "Andere";
 $Lang{CfgEdit_Title_User_Commands} = "Opdrachten van gebruiker";
 $Lang{CfgEdit_Title_Hosts} = "Machines";
 
@@ -1454,6 +1460,7 @@ $Lang{CfgEdit_Button_Delete}   = "Verwijderen";
 $Lang{CfgEdit_Button_Add}      = "Toevoegen";
 $Lang{CfgEdit_Button_Override} = "Overschrijven";
 $Lang{CfgEdit_Button_New_Key}  = "Nieuwe sleutel";
+$Lang{CfgEdit_Button_New_Share} = "New ShareName or '*'";
 
 $Lang{CfgEdit_Error_No_Save}
             = "Fout: niet bewaard ten gevolge van fouten";
