@@ -11,7 +11,7 @@
 #   Craig Barratt  <cbarratt@users.sourceforge.net>
 #
 # COPYRIGHT
-#   Copyright (C) 2001-2015  Craig Barratt
+#   Copyright (C) 2001-2017  Craig Barratt
 #
 #   This program is free software; you can redistribute it and/or modify
 #   it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@
 #
 #========================================================================
 #
-# Version 3.3.1, released 11 Jan 2015.
+# Version 3.3.2, released 25 Jan 2017.
 #
 # See http://backuppc.sourceforge.net.
 #
@@ -217,6 +217,8 @@ sub readOutput
         # This section is highly dependent on the version of smbclient.
         # If you upgrade Samba, make sure that these regexp are still valid.
         #
+        # MAKSYM 14082016: The next regex will never match on Samba-4.3, as
+        # smbclient doesn't produce output required; keeping it for older Sambas
         if ( /^\s*(-?\d+) \(\s*\d+[.,]\d kb\/s\) (.*)$/ ) {
             my $sambaFileSize = $1;
             my $pcFileName    = $2;
@@ -230,10 +232,15 @@ sub readOutput
             $t->{byteCnt} += $2;
             $t->{fileCnt}++;
             $t->{XferLOG}->write(\"$_\n") if ( $t->{logLevel} >= 1 );
-        } elsif ( /^\s*tar: dumped \d+ files/
-                    || /Total bytes received: \d+/i
-		) {
+        } elsif ( /^\s*tar: dumped (\d+) files/) {
+            # MAKSYM 14082016: Updating file count to the likely number
             $t->{xferOK} = 1;
+            $t->{fileCnt} = $1;
+            $t->{XferLOG}->write(\"$_\n") if ( $t->{logLevel} >= 0 );
+        } elsif ( /^\s*tar:\d+\s*Total bytes received: (\d+)/) {
+            # MAKSYM 14082016: Updating byte count to the likely number
+            $t->{xferOK} = 1;
+            $t->{byteCnt} = $1;
             $t->{XferLOG}->write(\"$_\n") if ( $t->{logLevel} >= 0 );
         } elsif ( /^\s*tar: restored \d+ files/ ) {
             $t->{xferOK} = 1;
@@ -272,7 +279,8 @@ sub readOutput
         } elsif ( /^\s*directory \\/i ) {
             $t->{XferLOG}->write(\"$_\n") if ( $t->{logLevel} >= 2 );
         } elsif ( /smb: \\>/
-                || /^tar:\d+/
+                || /^\s*tar:\d+/ # MAKSYM 14082016: ignoring 2 more Samba-4.3 specific lines
+                || /^\s*WARNING:/i
                 || /^\s*added interface/i
                 || /^\s*tarmode is now/i
                 || /^\s*Total bytes written/i
